# Vex-Cog-Utils

Utility functions for the Vex-Cogs repo.

There is nothing stopping you from using this in your own cogs, however some of the stuff here is geared towards my cogs. I would recommend you pin the version.
Example of pinned install in info.json: ``git+https://github.com/Vexed01/vex-cog-utils.git@v1.0.0``

Docstrings fully document each function.

## Versioning

``major.minor.micro``

Major and minor releases are likely to include breaking changes. There will be nothing breaking in micro releases.

## Changelog

I will endeavour to keep a basic changelog in the ``CHANGELOG.md`` file.

## Contributing

If you want to open a PR, go ahead! I don't really see much need as this is geared towards my cogs but I will probably accept it.

This repo as some tests in tox and a checks workflow.

## PyPi

I have no intentions to publish this on PyPi in the near future. If I do, the likely reasoning would be to do it as a learning experience.
